/**
 *  Call our require.ensure under the attached context. Therefore,
 *  require.ensure must reference only global closure variables.
 */

module.exports = function() {
  require.ensure.apply(this, arguments);
};
