/**
 *  Just run the callback through setImmediate, so that it appears
 *  asynchronous, even when unnecessary.
 */

function ensure(modules, callback) {
  setImmediate(callback);
}

module.exports = ensure;
